.. currentmodule:: numpy

==========================
NumPy 1.23.3 Release Notes
==========================
NumPy 1.23.3 is a maintenance release that fixes bugs discovered after the
1.23.2 release. There is no major theme for this release, the main improvements
are for some downstream builds and some annotation corner cases. The Python
versions supported for this release are 3.8-3.11.

Note that we will move to MacOS 11 for the NumPy 1.23.4 release, the 10.15
version currently used will no longer be supported by our build infrastructure
at that point.

Contributors
============

A total of 16 people contributed to this release.  People with a "+" by their
names contributed a patch for the first time.

* Aaron Meurer
* Bas van Beek
* Charles Harris
* Ganesh Kathiresan
* Gavin Zhang +
* Iantra Solari+
* Jyn Spring 琴春 +
* Matti Picus
* Rafael Cardoso Fernandes Sousa
* Rafael Sousa +
* Ralf Gommers
* Rin Cat (鈴猫) +
* Saransh Chopra +
* Sayed Adel
* Sebastian Berg
* Serge Guelton

Pull requests merged
====================

A total of 14 pull requests were merged for this release.

* `#22136 <https://github.com/numpy/numpy/pull/22136>`__: BLD: Add Python 3.11 wheels to aarch64 build
* `#22148 <https://github.com/numpy/numpy/pull/22148>`__: MAINT: Update setup.py for Python 3.11.
* `#22155 <https://github.com/numpy/numpy/pull/22155>`__: CI: Test NumPy build against old versions of GCC(6, 7, 8)
* `#22156 <https://github.com/numpy/numpy/pull/22156>`__: MAINT: support IBM i system
* `#22195 <https://github.com/numpy/numpy/pull/22195>`__: BUG: Fix circleci build
* `#22214 <https://github.com/numpy/numpy/pull/22214>`__: BUG: Expose heapsort algorithms in a shared header
* `#22215 <https://github.com/numpy/numpy/pull/22215>`__: BUG: Support using libunwind for backtrack
* `#22216 <https://github.com/numpy/numpy/pull/22216>`__: MAINT: fix an incorrect pointer type usage in f2py
* `#22220 <https://github.com/numpy/numpy/pull/22220>`__: BUG: change overloads to play nice with pyright.
* `#22221 <https://github.com/numpy/numpy/pull/22221>`__: TST,BUG: Use fork context to fix MacOS savez test
* `#22222 <https://github.com/numpy/numpy/pull/22222>`__: TYP,BUG: Reduce argument validation in C-based ``__class_getitem__``
* `#22223 <https://github.com/numpy/numpy/pull/22223>`__: TST: ensure ``np.equal.reduce`` raises a ``TypeError``
* `#22224 <https://github.com/numpy/numpy/pull/22224>`__: BUG: Fix the implementation of numpy.array_api.vecdot
* `#22230 <https://github.com/numpy/numpy/pull/22230>`__: BUG: Better report integer division overflow (backport)
